# pypi-info

🐍 PyPI Package Information Tool - Get detailed info about Python packages

## usage
```bash:
Usage: pypi-info [-h] [-l] [-d] [-p PATH] [--version-download VERSION_DOWNLOAD] [--author] [--home] [--tags] [--urls] [-s] [-r]
                 [-v]
                 [package]

🐍 PyPI Package Information Tool - Get detailed info about Python packages

Positional Arguments:
  package               📦 Package name or search query

Options:
  -h, --help            show this help message and exit
  -l, --last            🔍 Show only the latest version information
  -d, --download        📥 Download the package with progress bar
  -p, --path PATH       📁 Directory path to save downloaded files (default: current directory)
  --version-download VERSION_DOWNLOAD
                        🔢 Specific version to download (default: latest)
  --author              👤 Show author information
  --home                🏠 Show home page URL
  --tags                🏷️ Show package classifiers/tags
  --urls                🔗 Show all project URLs
  -s, --search-only     🔍 Show search results only, don't fetch detailed info
  -r, --requirements    📋 Show package requirements/dependencies
  -v, --version         Show version
```

## author
[Hadi Cahyadi](mailto:cumulus13@gmail.com)

## requirements
- rich
- rich_argparse

[![Buy Me a Coffee](https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png)](https://www.buymeacoffee.com/cumulus13)

[![Donate via Ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/cumulus13)

[Support me on Patreon](https://www.patreon.com/cumulus13)